"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BroadlinkPlatform = void 0;
const broadlink = __importStar(require("node-broadlink"));
const LC1Switch_1 = require("./LC1Switch");
const settings_1 = require("./settings");
class BroadlinkPlatform {
    constructor(log, config, api) {
        this.log = log;
        this.config = config;
        this.api = api;
        this.Service = this.api.hap.Service;
        this.Characteristic = this.api.hap.Characteristic;
        this.accessories = [];
        this.log.debug('Finished initializing platform:', this.config.name);
        this.api.on('didFinishLaunching', () => {
            log.debug('Executed didFinishLaunching callback');
            this.discoverDevices();
        });
    }
    configureAccessory(accessory) {
        this.log.info('Loading accessory from cache:', accessory.displayName);
        this.accessories.push(accessory);
    }
    async discoverDevices() {
        const devices = await broadlink.discover();
        for (const device of devices) {
            if (device.deviceType === 42573) {
                const hub = device;
                await hub.auth();
                const subdevices = await hub.getSubDevices();
                subdevices.forEach(async (subdevice, index) => {
                    const { host } = hub;
                    // @ts-expect-error: getSubDevices returns wrong type
                    const uniqueId = subdevice.did;
                    // @ts-expect-error: getSubDevices returns wrong type
                    const deviceName = subdevice.name;
                    const status = await hub.getState(uniqueId);
                    const uuid = this.api.hap.uuid.generate(uniqueId);
                    const existingAccessory = this.accessories.find(accessory => accessory.UUID === uuid);
                    if (existingAccessory) {
                        // the accessory already exists
                        this.log.info('Restoring existing accessory from cache:', existingAccessory.displayName);
                        new LC1Switch_1.LC1Switch(this, existingAccessory);
                    }
                    else {
                        this.log.info('Adding new accessory:', deviceName);
                        const gangs = [status.pwr1, status.pwr2, status.pwr3].filter(v => v !== void 0).length;
                        const accessory = new this.api.platformAccessory(`#${index} LC1 ${gangs} Gang Switch`, uuid);
                        accessory.context.device = {
                            uniqueId,
                            host,
                            deviceName,
                            status,
                            gangs,
                        };
                        new LC1Switch_1.LC1Switch(this, accessory);
                        this.api.registerPlatformAccessories(settings_1.PLUGIN_NAME, settings_1.PLATFORM_NAME, [
                            accessory,
                        ]);
                    }
                });
            }
        }
    }
}
exports.BroadlinkPlatform = BroadlinkPlatform;
//# sourceMappingURL=platform.js.map